use serde::{Deserialize, Serialize};
use std::fmt::{Display, Formatter};

#[derive(Debug, Serialize, Deserialize, Clone)]
pub enum NodeType {
    #[serde(rename = "master")]
    Master,
    #[serde(rename = "relay")]
    Relay {
        master_address: String
    },
    #[serde(rename = "subnet")]
    Subnet {
        master_address: String
    },
}

impl Display for NodeType {
    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
        match self {
            NodeType::Master => write!(f, "master"),
            NodeType::Relay { .. } => write!(f, "relay"),
            NodeType::Subnet { .. } => write!(f, "subnet"),
        }
    }
}

impl Default for NodeType {
    fn default() -> Self {
        Self::Master
    }
}

#[derive(Debug, Serialize, Deserialize, Default, Clone)]
pub struct NodeConfig {
    #[serde(rename = "type")]
    pub node_type: NodeType,
    pub device_id: Option<String>
}
